read README.md
read CONTRIBUTING.md

don't EVER use 'general-purpose' agents. They get stuck and hang forever.
don't EVER run `just release` without being explicitly told. Always ask for permission.
unless told otherwise, always work in a separate worktree and clean it up after merging it back to the branch you started from.